@@ -1,7 +1,7 @@
 #ifndef __PExpr_H
 #define __PExpr_H
 /*
- * Copyright (c) 1998-2009 Stephen Williams <steve@icarus.com>
+ * Copyright (c) 1998-2010 Stephen Williams <steve@icarus.com>
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -307,7 +307,8 @@ class PEIdent : public PExpr {
       NetExpr* calculate_up_do_base_(Design*, NetScope*) const;
       bool calculate_param_range_(Design*, NetScope*,
 				  const NetExpr*msb_ex, long&msb,
-				  const NetExpr*lsb_ex, long&lsb) const;
+				  const NetExpr*lsb_ex, long&lsb,
+				  long length) const;
 
       bool calculate_up_do_width_(Design*, NetScope*, unsigned long&wid) const;
 
@@ -532,6 +533,10 @@ class PEBComp  : public PEBinary {
       NetExpr* elaborate_expr(Design*des, NetScope*scope,
 			      int expr_width, bool sys_task_arg) const;
       NetExpr*elaborate_pexpr(Design*des, NetScope*sc) const;
+
+    private:
+      int left_width_;
+      int right_width_;
 };
 
 /*
@@ -673,6 +678,8 @@ class PECallFunction : public PExpr {
 
       bool check_call_matches_definition_(Design*des, NetScope*dscope) const;
 
+      NetExpr* cast_to_width_(NetExpr*expr, int wid, bool signed_flag) const;
+
       NetExpr* elaborate_sfunc_(Design*des, NetScope*scope, int expr_wid) const;
       NetExpr* elaborate_access_func_(Design*des, NetScope*scope, ivl_nature_t) const;
       unsigned test_width_sfunc_(Design*des, NetScope*scope,
