@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1999-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -23,7 +23,7 @@
 # include  <iostream>
 # include  <cstdlib>
 # include  <cstring>
-# include  <math.h>
+# include  <cmath>
 
 # include  "netlist.h"
 # include  "ivl_assert.h"
@@ -858,7 +858,7 @@ NetExpr* NetEBDiv::eval_tree(int prune_to_width)
       eval_expr(right_);
 
       if (expr_type() == IVL_VT_REAL) return eval_tree_real_();
-      
+
       assert(expr_type() == IVL_VT_LOGIC);
 
       NetEConst*lc = dynamic_cast<NetEConst*>(left_);
@@ -1228,38 +1228,52 @@ NetExpr* NetEParam::eval_tree(int prune_to_width)
 		 << *this << endl;
       }
 
+      if (solving()) {
+	    cerr << get_fileline() << ": warning: Recursive parameter "
+	            "reference found involving " << *this << "." << endl;
+	    return 0;
+      }
+
       assert(scope_);
       perm_string name = (*reference_).first;
       const NetExpr*expr = (*reference_).second.expr;
-      ivl_assert(*this, expr);
-
-      NetExpr*nexpr = expr->dup_expr();
-      assert(nexpr);
+	// Since constant user functions are not supported we can get
+	// parameters/localparams that are not defined. For now generate
+	// an appropriate error message.
+      if (expr == NULL) {
+	    cerr << get_fileline() << ": internal error: parameter/localparam "
+		 << *this << " cannot be evaluated." << endl;
+	    return 0;
+      }
 
 	// If the parameter that I refer to is already evaluated, then
 	// return the constant value.
-      if (NetEConst*tmp = dynamic_cast<NetEConst*>(nexpr)) {
+      if (const NetEConst*tmp = dynamic_cast<const NetEConst*>(expr)) {
 	    verinum val = tmp->value();
 	    NetEConstParam*ptmp = new NetEConstParam(scope_, name, val);
 	    ptmp->set_line(*this);
-	    delete nexpr;
 	    return ptmp;
       }
 
-      if (NetECReal*tmp = dynamic_cast<NetECReal*>(nexpr)) {
+      if (const NetECReal*tmp = dynamic_cast<const NetECReal*>(expr)) {
 	    verireal val = tmp->value();
 	    NetECRealParam*ptmp = new NetECRealParam(scope_, name, val);
 	    ptmp->set_line(*this);
-	    delete nexpr;
 	    return ptmp;
       }
 
 	// Try to evaluate the expression. If I cannot, then the
 	// expression is not a constant expression and I fail here.
+
+      solving(true);
+      NetExpr*nexpr = expr->dup_expr();
+      assert(nexpr);
       NetExpr*res = nexpr->eval_tree();
+      solving(false);
       if (res == 0) {
-	    cerr << get_fileline() << ": internal error: Unable to evaluate "
-		 << "parameter " << name << " expression: "
+	    cerr << get_fileline() << ": internal error: Unable to evaluate ";
+	    if (expr_type() == IVL_VT_REAL) cerr << "real ";
+	    cerr << "parameter " << name << " expression: "
 		 << *nexpr << endl;
 	    delete nexpr;
 	    return 0;
@@ -1742,8 +1756,6 @@ NetExpr* evaluate_math_one_arg(NetExpr*&arg_, const char*name)
 
 	    if (strcmp(name, "$ln") == 0) {
 		  return new NetECReal(verireal(log(arg)));
-	    } else if (strcmp(name, "$log") == 0) {
-		  return new NetECReal(verireal(log10(arg)));
 	    } else if (strcmp(name, "$log10") == 0) {
 		  return new NetECReal(verireal(log10(arg)));
 	    } else if (strcmp(name, "$exp") == 0) {
@@ -1941,18 +1953,14 @@ NetExpr* NetESFunc::eval_tree(int prune_to_width)
       }
 
       if ((gn_icarus_misc_flag || gn_verilog_ams_flag) &&
-          (strcmp(nm, "$log") == 0 || strcmp(nm, "$abs") == 0)) {
+          (strcmp(nm, "$abs") == 0)) {
 	    if (nparms() != 1 || parm(0) == 0) {
 		  cerr << get_fileline() << ": error: " << nm
 		       << " takes a single argument." << endl;
 		  return 0;
 	    }
 	    NetExpr*arg = parm(0)->dup_expr();
-	    if (strcmp(nm, "$log") == 0) {
-		  rtn = evaluate_math_one_arg(arg, nm);
-	    } else {
-		  rtn = evaluate_abs(arg);
-	    }
+	    rtn = evaluate_abs(arg);
 	    delete arg;
       }
 
