@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2000-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -22,15 +22,12 @@
 # include  <iostream>
 
 # include  <cstring>
-# include  <stdio.h>   // sprintf()
+# include  <cstdio> // sprintf()
 # include  "compiler.h"
 # include  "t-dll.h"
 # include  "netmisc.h"
 # include  "discipline.h"
-#ifdef HAVE_MALLOC_H
-# include  <malloc.h>
-#endif
-# include  <stdlib.h>
+# include  <cstdlib>
 # include  "ivl_assert.h"
 
 struct dll_target dll_target_obj;
