@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2001-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -20,9 +20,6 @@
 # include  "vvp_priv.h"
 # include  <string.h>
 # include  <assert.h>
-#ifdef HAVE_MALLOC_H
-# include  <malloc.h>
-#endif
 # include  <stdlib.h>
 
 #ifdef __MINGW32__ /* MinGW has inconsistent %p output. */
@@ -42,22 +39,6 @@ static unsigned transient_id = 0;
  * executable code for the processes.
  */
 
-unsigned bitchar_to_idx(char bit)
-{
-      switch (bit) {
-	  case '0':
-	    return 0;
-	  case '1':
-	    return 1;
-	  case 'x':
-	    return 2;
-	  case 'z':
-	    return 3;
-	  default:
-	    assert(0);
-	    return 0;
-      }
-}
 
 /*
  * These functions handle the blocking assignment. Use the %set
@@ -602,19 +583,11 @@ static int show_stmt_assign(ivl_statement_t net)
       lval = ivl_stmt_lval(net, 0);
 
       sig = ivl_lval_sig(lval);
-      if (sig) switch (ivl_signal_data_type(sig)) {
-
-	  case IVL_VT_REAL:
+      if (sig && (ivl_signal_data_type(sig) == IVL_VT_REAL)) {
 	    return show_stmt_assign_sig_real(net);
-
-	  default:
-	    return show_stmt_assign_vector(net);
-
-      } else {
-	    return show_stmt_assign_vector(net);
       }
 
-      return 0;
+      return show_stmt_assign_vector(net);
 }
 
 /*
@@ -782,10 +755,39 @@ static int show_stmt_assign_nb(ivl_statement_t net)
       }
 
 
-      { struct vector_info res = draw_eval_expr(rval, 0);
-        unsigned wid = res.wid;
+      { struct vector_info res;
+	unsigned wid;
 	unsigned lidx;
 	unsigned cur_rbit = 0;
+	  /* Handle the special case that the expression is a real
+	     value. Evaluate the real expression, then convert the
+	     result to a vector. */
+	if (ivl_expr_value(rval) == IVL_VT_REAL) {
+	      int word = draw_eval_real(rval);
+	        /* This is the accumulated with of the l-value of the
+		   assignment. */
+	      wid = ivl_stmt_lwidth(net);
+
+	      res.base = allocate_vector(wid);
+	      res.wid = wid;
+
+	      if (res.base == 0) {
+		    fprintf(stderr, "%s:%u: vvp.tgt error: "
+			    "Unable to allocate %u thread bits for "
+			    "r-value expression.\n", ivl_expr_file(rval),
+			    ivl_expr_lineno(rval), wid);
+		    vvp_errors += 1;
+	      }
+
+	      fprintf(vvp_out, "    %%cvt/vr %u, %d, %u;\n",
+		      res.base, word, res.wid);
+
+	      clr_word(word);
+
+	} else {
+	      res = draw_eval_expr(rval, 0);
+	      wid = res.wid;
+	}
 
 	for (lidx = 0 ;  lidx < ivl_stmt_lvals(net) ;  lidx += 1) {
 	      unsigned bit_limit = wid - cur_rbit;
@@ -840,6 +842,8 @@ static int show_stmt_block_named(ivl_statement_t net, ivl_scope_t scope)
       fprintf(vvp_out, "    %%fork t_%u, S_%p;\n",
 	      sub_id, subscope);
       fprintf(vvp_out, "    %%jmp t_%u;\n", out_id);
+	/* Change the compiling scope to be the named blocks scope. */
+      fprintf(vvp_out, "    .scope S_%p;\n", subscope);
       fprintf(vvp_out, "t_%u ;\n", sub_id);
 
 	/* The statement within the fork is in a new thread, so no
@@ -848,6 +852,8 @@ static int show_stmt_block_named(ivl_statement_t net, ivl_scope_t scope)
 
       rc = show_stmt_block(net, subscope);
       fprintf(vvp_out, "    %%end;\n");
+	/* Return to the previous scope. */
+      fprintf(vvp_out, "    .scope S_%p;\n", scope);
 
       fprintf(vvp_out, "t_%u %%join;\n", out_id);
       clear_expression_lookaside();
@@ -859,8 +865,8 @@ static int show_stmt_block_named(ivl_statement_t net, ivl_scope_t scope)
 static int show_stmt_case(ivl_statement_t net, ivl_scope_t sscope)
 {
       int rc = 0;
-      ivl_expr_t exp = ivl_stmt_cond_expr(net);
-      struct vector_info cond = draw_eval_expr(exp, 0);
+      ivl_expr_t expr = ivl_stmt_cond_expr(net);
+      struct vector_info cond = draw_eval_expr(expr, 0);
       unsigned count = ivl_stmt_case_count(net);
 
       unsigned local_base = local_count;
@@ -976,8 +982,8 @@ static int show_stmt_case(ivl_statement_t net, ivl_scope_t sscope)
 static int show_stmt_case_r(ivl_statement_t net, ivl_scope_t sscope)
 {
       int rc = 0;
-      ivl_expr_t exp = ivl_stmt_cond_expr(net);
-      int cond = draw_eval_real(exp);
+      ivl_expr_t expr = ivl_stmt_cond_expr(net);
+      int cond = draw_eval_real(expr);
       unsigned count = ivl_stmt_case_count(net);
 
       unsigned local_base = local_count;
@@ -1316,9 +1322,9 @@ static int show_stmt_condit(ivl_statement_t net, ivl_scope_t sscope)
 {
       int rc = 0;
       unsigned lab_false, lab_out;
-      ivl_expr_t exp = ivl_stmt_cond_expr(net);
+      ivl_expr_t expr = ivl_stmt_cond_expr(net);
       struct vector_info cond
-	    = draw_eval_expr(exp, STUFF_OK_XZ|STUFF_OK_47|STUFF_OK_RO);
+	    = draw_eval_expr(expr, STUFF_OK_XZ|STUFF_OK_47|STUFF_OK_RO);
 
       assert(cond.wid == 1);
 
@@ -1389,14 +1395,14 @@ static int show_stmt_delay(ivl_statement_t net, ivl_scope_t sscope)
 static int show_stmt_delayx(ivl_statement_t net, ivl_scope_t sscope)
 {
       int rc = 0;
-      ivl_expr_t exp = ivl_stmt_delay_expr(net);
+      ivl_expr_t expr = ivl_stmt_delay_expr(net);
       ivl_statement_t stmt = ivl_stmt_sub_stmt(net);
 
-      switch (ivl_expr_value(exp)) {
+      switch (ivl_expr_value(expr)) {
 
 	  case IVL_VT_BOOL:
 	  case IVL_VT_LOGIC: {
-		struct vector_info del = draw_eval_expr(exp, 0);
+		struct vector_info del = draw_eval_expr(expr, 0);
 		fprintf(vvp_out, "    %%ix/get 0, %u, %u;\n",
 			del.base, del.wid);
 		clr_vector(del);
@@ -1404,7 +1410,7 @@ static int show_stmt_delayx(ivl_statement_t net, ivl_scope_t sscope)
 	  }
 
 	  case IVL_VT_REAL: {
-		int word = draw_eval_real(exp);
+		int word = draw_eval_real(expr);
 		fprintf(vvp_out, "    %%cvt/ir 0, %d;\n", word);
 		clr_word(word);
 		break;
@@ -1482,23 +1488,22 @@ static int show_stmt_fork(ivl_statement_t net, ivl_scope_t sscope)
       int rc = 0;
       unsigned cnt = ivl_stmt_block_count(net);
       ivl_scope_t scope = ivl_stmt_block_scope(net);
+      unsigned is_named = (scope != 0);
 
       unsigned out = transient_id++;
       unsigned id_base = transient_id;
 
 	/* cnt is the number of sub-threads. If the fork-join has no
 	   name, then we can put one of the sub-threads in the current
-	   thread, so decrement the count by one. */
-      if (scope == 0) {
+	   thread, so decrement the count by one and use the current
+	   scope for all the threads. */
+      if (! is_named) {
 	    cnt -= 1;
 	    scope = sscope;
       }
 
       transient_id += cnt;
 
-	/* If no subscope use provided */
-      if (!scope) scope = sscope;
-
 	/* Draw a fork statement for all but one of the threads of the
 	   fork/join. Send the threads off to a bit of code where they
 	   are implemented. */
@@ -1509,7 +1514,7 @@ static int show_stmt_fork(ivl_statement_t net, ivl_scope_t sscope)
 
 	/* If we are putting one sub-thread into the current thread,
 	   then draw its code here. */
-      if (ivl_stmt_block_scope(net) == 0)
+      if (! is_named)
 	    rc += show_statement(ivl_stmt_block_stmt(net, cnt), scope);
 
 
@@ -1519,6 +1524,8 @@ static int show_stmt_fork(ivl_statement_t net, ivl_scope_t sscope)
       }
       fprintf(vvp_out, "    %%jmp t_%u;\n", out);
 
+	/* Change the compiling scope to be the named forks scope. */
+      if (is_named) fprintf(vvp_out, "    .scope S_%p;\n", scope);
 	/* Generate the sub-threads themselves. */
       for (idx = 0 ;  idx < cnt ;  idx += 1) {
 	    fprintf(vvp_out, "t_%u ;\n", id_base+idx);
@@ -1526,6 +1533,8 @@ static int show_stmt_fork(ivl_statement_t net, ivl_scope_t sscope)
 	    rc += show_statement(ivl_stmt_block_stmt(net, idx), scope);
 	    fprintf(vvp_out, "    %%end;\n");
       }
+	/* Return to the previous scope. */
+      if (is_named) fprintf(vvp_out, "    .scope S_%p;\n", sscope);
 
 	/* This is the label for the out. Use this to branch around
 	   the implementations of all the child threads. */
@@ -1623,9 +1632,9 @@ static int show_stmt_repeat(ivl_statement_t net, ivl_scope_t sscope)
 {
       int rc = 0;
       unsigned lab_top = local_count++, lab_out = local_count++;
-      ivl_expr_t exp = ivl_stmt_cond_expr(net);
-      struct vector_info cnt = draw_eval_expr(exp, 0);
-      char *sign = ivl_expr_signed(exp) ? "s" : "u";
+      ivl_expr_t expr = ivl_stmt_cond_expr(net);
+      struct vector_info cnt = draw_eval_expr(expr, 0);
+      char *sign = ivl_expr_signed(expr) ? "s" : "u";
 
 	/* Test that 0 < expr */
       fprintf(vvp_out, "T_%u.%u %%cmp/%s 0, %u, %u;\n", thread_count,
