@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2001-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -18,9 +18,6 @@
  */
 
 # include  "vvp_priv.h"
-#ifdef HAVE_MALLOC_H
-# include  <malloc.h>
-#endif
 # include  <stdlib.h>
 # include  <math.h>
 # include  <string.h>
@@ -817,14 +814,15 @@ static void draw_logic_in_scope(ivl_net_logic_t lptr)
 	/* Get all the input label that I will use for parameters to
 	   the functor that I create later. */
       ninp = ivl_logic_pins(lptr) - 1;
+      assert(ninp >= 0);
       input_strings = calloc(ninp, sizeof(char*));
-      for (pdx = 0 ;  pdx < ninp ;  pdx += 1)
+      for (pdx = 0 ;  pdx < (unsigned)ninp ;  pdx += 1)
 	    input_strings[pdx] = draw_net_input(ivl_logic_pin(lptr, pdx+1));
 
       level = 0;
       while (ninp) {
-	    int inst;
-	    for (inst = 0; inst < ninp; inst += 4) {
+	    unsigned inst;
+	    for (inst = 0; inst < (unsigned)ninp; inst += 4) {
 		  if (ninp > 4)
 			fprintf(vvp_out, "L_%p/%d/%d .functor %s %u",
 				lptr, level, inst, lcasc, vector_width);
@@ -837,7 +835,7 @@ static void draw_logic_in_scope(ivl_net_logic_t lptr)
 			      fprintf(vvp_out, " [%u %u]", str0, str1);
 
 		  }
-		  for (pdx = inst; pdx < ninp && pdx < inst+4 ; pdx += 1) {
+		  for (pdx = inst; pdx < (unsigned)ninp && pdx < inst+4 ; pdx += 1) {
 			if (level) {
 			      fprintf(vvp_out, ", L_%p/%d/%d",
 				      lptr, level - 1, pdx*4);
@@ -881,17 +879,6 @@ static void draw_logic_in_scope(ivl_net_logic_t lptr)
 		  assert(! number_is_unknown(fall_exp));
 		  assert(! number_is_unknown(decay_exp));
 
-		  // .delay (x,y,z) only supports a 64 bit delay value.
-		  if ((! number_is_immediate(rise_exp, 64, 0)) ||
-		      (! number_is_immediate(fall_exp, 64, 0)) ||
-		      (! number_is_immediate(decay_exp, 64, 0))) {
-			fprintf(stderr, "%s:%u: vvp-tgt sorry: only 64 bit "
-			        "delays are supported in a continuous "
-			        "assignment.\n", ivl_expr_file(rise_exp),
-			        ivl_expr_lineno(rise_exp));
-			assert(0);
-		  }
-
 		  fprintf(vvp_out, "L_%p .delay (%" PRIu64 ",%" PRIu64 ",%" PRIu64 ") L_%p/d;\n",
 			  lptr, get_number_immediate64(rise_exp),
 			  get_number_immediate64(fall_exp),
@@ -905,7 +892,7 @@ static void draw_logic_in_scope(ivl_net_logic_t lptr)
 		  assert(ivl_expr_type(fall_exp) == IVL_EX_SIGNAL);
 		  assert(ivl_expr_type(decay_exp) == IVL_EX_SIGNAL);
 
-		  fprintf(vvp_out, "L_%p .delay  L_%p/d", lptr, lptr);
+		  fprintf(vvp_out, "L_%p .delay L_%p/d", lptr, lptr);
 
 		  sig = ivl_expr_signal(rise_exp);
 		  assert(ivl_signal_dimensions(sig) == 0);
@@ -1102,20 +1089,9 @@ static const char* draw_lpm_output_delay(ivl_lpm_t net)
 	    assert(! number_is_unknown(d_fall));
 	    assert(! number_is_unknown(d_decay));
 
-	    // .delay (x,y,z) only supports a 64 bit delay value.
-	    if ((! number_is_immediate(d_rise, 64, 0)) ||
-	        (! number_is_immediate(d_fall, 64, 0)) ||
-	        (! number_is_immediate(d_decay, 64, 0))) {
-		  fprintf(stderr, "%s:%u: vvp-tgt sorry: only 64 bit "
-		          "delays are supported in a continuous "
-		          "assignment.\n", ivl_expr_file(d_rise),
-		          ivl_expr_lineno(d_rise));
-		  assert(0);
-	    }
-
 	    dly = "/d";
 	    fprintf(vvp_out, "L_%p .delay (%" PRIu64 ",%" PRIu64 ",%" PRIu64 ")"
-		    "L_%p/d;\n", net, get_number_immediate64(d_rise),
+		    " L_%p/d;\n", net, get_number_immediate64(d_rise),
 	            get_number_immediate64(d_fall),
 	            get_number_immediate64(d_decay), net);
       }
@@ -1692,7 +1668,11 @@ static void draw_lpm_part(ivl_lpm_t net)
 	    if (ivl_lpm_signed(net) && width_of_nexus(sel) < 8*sizeof(int)) {
 		  fprintf(stderr, "%s:%u: tgt-vvp warning: V0.9 may give "
 		                  "incorrect results for a select with a "
+#ifdef __MINGW32__  /* MinGW does not know about z. */
+		                  "signed index less than %u bits.\n",
+#else
 		                  "signed index less than %zu bits.\n",
+#endif
 		                  ivl_lpm_file(net), ivl_lpm_lineno(net),
 		                  8*sizeof(int));
 	    }
