@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1999-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -17,9 +17,6 @@
  *    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-# include "vpi_config.h"
-
-# include  "vpi_user.h"
 # include  "sys_priv.h"
 # include  <assert.h>
 # include  <string.h>
@@ -268,7 +265,8 @@ static unsigned int get_format_char(char **rtn, int ljust, int plus,
   unsigned int ini_size = 512;  /* The initial size of the buffer. */
 
   /* Make sure the width fits in the initial buffer. */
-  if (width+1 > ini_size) ini_size = width + 1;
+  assert(width >= -1);
+  if ((unsigned int)(width+1) > ini_size) ini_size = width + 1;
 
   /* The default return value is the full format. */
   result = malloc(ini_size*sizeof(char));
@@ -1233,7 +1231,7 @@ static PLI_INT32 sys_strobe_calltf(PLI_BYTE8*name)
 {
       vpiHandle callh, argv, scope;
       struct t_cb_data cb;
-      struct t_vpi_time time;
+      struct t_vpi_time timerec;
       struct strobe_cb_info*info;
       PLI_UINT32 fd_mcd;
 
@@ -1283,13 +1281,13 @@ static PLI_INT32 sys_strobe_calltf(PLI_BYTE8*name)
       info->scope= scope;
       array_from_iterator(info, argv);
 
-      time.type = vpiSimTime;
-      time.low = 0;
-      time.high = 0;
+      timerec.type = vpiSimTime;
+      timerec.low = 0;
+      timerec.high = 0;
 
       cb.reason = cbReadOnlySynch;
       cb.cb_rtn = strobe_cb;
-      cb.time = &time;
+      cb.time = &timerec;
       cb.obj = 0;
       cb.value = 0;
       cb.user_data = (char*)info;
@@ -1342,7 +1340,7 @@ static PLI_INT32 monitor_cb_2(p_cb_data cb)
 static PLI_INT32 monitor_cb_1(p_cb_data cause)
 {
       struct t_cb_data cb;
-      struct t_vpi_time time;
+      struct t_vpi_time timerec;
 
       if (monitor_enabled == 0) return 0;
       if (monitor_scheduled) return 0;
@@ -1351,13 +1349,13 @@ static PLI_INT32 monitor_cb_1(p_cb_data cause)
 	   the monitor to happen at the end of the time slice and mark
 	   it as scheduled. */
       monitor_scheduled += 1;
-      time.type = vpiSimTime;
-      time.low = 0;
-      time.high = 0;
+      timerec.type = vpiSimTime;
+      timerec.low = 0;
+      timerec.high = 0;
 
       cb.reason = cbReadOnlySynch;
       cb.cb_rtn = monitor_cb_2;
-      cb.time = &time;
+      cb.time = &timerec;
       cb.obj = 0;
       cb.value = 0;
       vpi_register_cb(&cb);
@@ -1379,7 +1377,7 @@ static PLI_INT32 sys_monitor_calltf(PLI_BYTE8*name)
       vpiHandle callh, argv, scope;
       unsigned idx;
       struct t_cb_data cb;
-      struct t_vpi_time time;
+      struct t_vpi_time timerec;
 
       callh = vpi_handle(vpiSysTfCall, 0);
       argv = vpi_iterate(vpiArgument, callh);
@@ -1415,10 +1413,10 @@ static PLI_INT32 sys_monitor_calltf(PLI_BYTE8*name)
 	/* Attach callbacks to all the parameters that might change. */
       monitor_callbacks = calloc(monitor_info.nitems, sizeof(vpiHandle));
 
-      time.type = vpiSuppressTime;
+      timerec.type = vpiSuppressTime;
       cb.reason = cbValueChange;
       cb.cb_rtn = monitor_cb_1;
-      cb.time = &time;
+      cb.time = &timerec;
       cb.value = NULL;
       for (idx = 0 ;  idx < monitor_info.nitems ;  idx += 1) {
 
@@ -1879,6 +1877,30 @@ void sys_display_register()
       tf_data.user_data = "$display";
       vpi_register_systf(&tf_data);
 
+      tf_data.type      = vpiSysTask;
+      tf_data.tfname    = "$info";
+      tf_data.calltf    = sys_display_calltf;
+      tf_data.compiletf = sys_display_compiletf;
+      tf_data.sizetf    = 0;
+      tf_data.user_data = "$display";
+      vpi_register_systf(&tf_data);
+
+      tf_data.type      = vpiSysTask;
+      tf_data.tfname    = "$warning";
+      tf_data.calltf    = sys_display_calltf;
+      tf_data.compiletf = sys_display_compiletf;
+      tf_data.sizetf    = 0;
+      tf_data.user_data = "$display";
+      vpi_register_systf(&tf_data);
+
+      tf_data.type      = vpiSysTask;
+      tf_data.tfname    = "$error";
+      tf_data.calltf    = sys_display_calltf;
+      tf_data.compiletf = sys_display_compiletf;
+      tf_data.sizetf    = 0;
+      tf_data.user_data = "$display";
+      vpi_register_systf(&tf_data);
+
       tf_data.type      = vpiSysTask;
       tf_data.tfname    = "$displayh";
       tf_data.calltf    = sys_display_calltf;
