@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2003-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -17,7 +17,6 @@
  *    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-# include  "vpi_user.h"
 # include  "sys_priv.h"
 # include  <assert.h>
 # include  <ctype.h>
@@ -547,7 +546,7 @@ static unsigned fread_word(FILE *fp, vpiHandle word,
 	 * my local vector. */
       val.format = vpiVectorVal;
       vpi_get_value(word, &val);
-      for (bidx = 0; bidx < words; bidx += 1) {
+      for (bidx = 0; (unsigned)bidx < words; bidx += 1) {
 	    vector[bidx].aval = val.value.vector[bidx].aval;
 	    vector[bidx].bval = val.value.vector[bidx].bval;
       }
@@ -684,9 +683,10 @@ static PLI_INT32 sys_fread_calltf(PLI_BYTE8*name)
       vector = calloc(words, sizeof(s_vpi_vecval));
       bpe = (width+7)/8;
 
+      assert(count >= 0);
       if (is_mem) {
 	    rtn = 0;
-	    for (idx = 0; idx < count; idx += 1) {
+	    for (idx = 0; idx < (unsigned)count; idx += 1) {
 		  vpiHandle word;
 		  word = vpi_handle_by_index(mem_reg, start+(signed)idx);
 		  rtn += fread_word(fp, word, words, bpe, vector);
