@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2003-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -17,26 +17,20 @@
  *    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-/* The vpi_config.h include must be before the lxt2_write.h include! */
-# include "vpi_config.h"
-# include "lxt2_write.h"
+/* The sys_priv.h include must be before the lxt2_write.h include! */
 # include "sys_priv.h"
+# include "lxt2_write.h"
 # include "vcd_priv.h"
 
 /*
- * This file contains the implementations of the LXT2 related
- * funcitons.
+ * This file contains the implementations of the LXT2 related functions.
  */
 
-# include  "vpi_user.h"
 # include  <stdio.h>
 # include  <stdlib.h>
 # include  <string.h>
 # include  <assert.h>
 # include  <time.h>
-#ifdef HAVE_MALLOC_H
-# include  <malloc.h>
-#endif
 # include  "stringheap.h"
 
 
@@ -568,8 +562,8 @@ static void scan_item(unsigned depth, vpiHandle item, int skip)
 		    /* Turn a non-constant array word select into a
 		     * constant word select. */
 		  vpiHandle array = vpi_handle(vpiParent, item);
-		  PLI_INT32 index = vpi_get(vpiIndex, item);
-		  item = vpi_handle_by_index(array, index);
+		  PLI_INT32 idx = vpi_get(vpiIndex, item);
+		  item = vpi_handle_by_index(array, idx);
 	    }
 	  case vpiIntegerVar:
 	  case vpiTimeVar:
@@ -741,13 +735,13 @@ static PLI_INT32 sys_dumpvars_calltf(PLI_BYTE8*name)
       if (dump_file == 0) {
 	    open_dumpfile(callh);
 	    if (dump_file == 0) {
-		  vpi_free_object(argv);
+		  if (argv) vpi_free_object(argv);
 		  return 0;
 	    }
       }
 
       if (install_dumpvars_callback()) {
-	    vpi_free_object(argv);
+	    if (argv) vpi_free_object(argv);
 	    return 0;
       }
 
@@ -770,8 +764,9 @@ static PLI_INT32 sys_dumpvars_calltf(PLI_BYTE8*name)
 
 	    int dep = draw_scope(item);
 
-	    vcd_names_sort(&lxt_tab);
 	    scan_item(depth, item, 0);
+	      /* The scope list must be sorted after we scan an item.  */
+	    vcd_names_sort(&lxt_tab);
 
 	    while (dep--) pop_scope();
       }
@@ -792,15 +787,21 @@ void sys_lxt2_register()
       s_vpi_systf_data tf_data;
 
 
-	/* Scan the extended arguments, looking for lxt optimization
+	/* Scan the extended arguments, looking for lxt2 optimization
 	   flags. */
       vpi_get_vlog_info(&vlog_info);
 
       for (idx = 0 ;  idx < vlog_info.argc ;  idx += 1) {
-	    if (strcmp(vlog_info.argv[idx],"-lxt-space") == 0) {
+	    if (strcmp(vlog_info.argv[idx],"-lxt2-space") == 0) {
 		  lxm_optimum_mode = LXM_SPACE;
 
-	    } else if (strcmp(vlog_info.argv[idx],"-lxt-speed") == 0) {
+	    } else if (strcmp(vlog_info.argv[idx],"-lxt2-speed") == 0) {
+		  lxm_optimum_mode = LXM_SPEED;
+
+	    } else if (strcmp(vlog_info.argv[idx],"-lx2-space") == 0) {
+		  lxm_optimum_mode = LXM_SPACE;
+
+	    } else if (strcmp(vlog_info.argv[idx],"-lx2-speed") == 0) {
 		  lxm_optimum_mode = LXM_SPEED;
 
 	    }
