@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1999-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -17,9 +17,6 @@
  *    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-# include "vpi_config.h"
-
-# include  "vpi_user.h"
 # include  "sys_priv.h"
 # include  <ctype.h>
 # include  <string.h>
@@ -450,7 +447,7 @@ static PLI_INT32 sys_readmempath_calltf(PLI_BYTE8*name)
 	 */
       len = strlen(val.value.str);
       for (idx = 0; idx < len; idx++) {
-	    if (! isprint(val.value.str[idx])) {
+	    if (! isprint((int)val.value.str[idx])) {
 		  char msg [64];
 		  char *esc_path = as_escaped(val.value.str);
 		  snprintf(msg, 64, "WARNING: %s:%d:",
