@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2006-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2006-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -21,7 +21,6 @@
 # define _ISOC99_SOURCE 1
 # define _SVID_SOURCE 1
 
-# include  "vpi_user.h"
 # include  "sys_priv.h"
 # include  <ctype.h>
 # include  <errno.h>
@@ -121,7 +120,7 @@ static double float_string(struct byte_source*src)
 	    }
 
 	    while (isdigit(ch)) {
-		  src = realloc(str, len+2);
+		  str = realloc(str, len+2);
 		  str[len++] = ch;
 		  ch = byte_getc(src);
 	    }
@@ -251,12 +250,12 @@ static int scan_format(vpiHandle callh, struct byte_source*src, vpiHandle argv)
 
       while ( fmtp && *fmtp != 0 && !match_fail) {
 
-	    if (isspace(*fmtp)) {
+	    if (isspace((int)*fmtp)) {
 		    /* White space matches a string of white space in
 		       the input. The number of spaces is not
 		       relevant, and the match may be 0 or more
 		       spaces. */
-		  while (*fmtp && isspace(*fmtp)) fmtp += 1;
+		  while (*fmtp && isspace((int)*fmtp)) fmtp += 1;
 
 		  ch = byte_getc(src);
 		  while (isspace(ch)) ch = byte_getc(src);
@@ -291,9 +290,9 @@ static int scan_format(vpiHandle callh, struct byte_source*src, vpiHandle argv)
 			suppress_flag = 1;
 			fmtp += 1;
 		  }
-		  if (isdigit(*fmtp)) {
+		  if (isdigit((int)*fmtp)) {
 			length_field = 0;
-			while (isdigit(*fmtp)) {
+			while (isdigit((int)*fmtp)) {
 			      length_field *= 10;
 			      length_field += *fmtp - '0';
 			      fmtp += 1;
