@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1999-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -21,19 +21,14 @@
 # include "vcd_priv.h"
 
 /*
- * This file contains the implementations of the VCD related
- * funcitons.
+ * This file contains the implementations of the VCD related functions.
  */
 
-# include  "vpi_user.h"
 # include  <stdio.h>
 # include  <stdlib.h>
 # include  <string.h>
 # include  <assert.h>
 # include  <time.h>
-#ifdef HAVE_MALLOC_H
-# include  <malloc.h>
-#endif
 
 static char *dump_path = NULL;
 static FILE *dump_file = NULL;
@@ -500,11 +495,11 @@ static void scan_item(unsigned depth, vpiHandle item, int skip)
       struct t_cb_data cb;
       struct vcd_info* info;
 
-      const char* type;
-      const char* name;
-      const char* fullname;
-      const char* prefix;
-      const char* ident;
+      const char *type;
+      const char *name;
+      const char *fullname;
+      const char *prefix;
+      const char *ident;
       int nexus_id;
       unsigned size;
       PLI_INT32 item_type;
@@ -576,8 +571,8 @@ static void scan_item(unsigned depth, vpiHandle item, int skip)
 	       * word select. */
 	    if (vpi_get(vpiConstantSelect, item) == 0) {
 		  vpiHandle array = vpi_handle(vpiParent, item);
-		  PLI_INT32 index = vpi_get(vpiIndex, item);
-		  item = vpi_handle_by_index(array, index);
+		  PLI_INT32 idx = vpi_get(vpiIndex, item);
+		  item = vpi_handle_by_index(array, idx);
 	    }
 
 	      /* An array word is implicitly escaped so look for an
@@ -602,7 +597,6 @@ static void scan_item(unsigned depth, vpiHandle item, int skip)
 
 	  case vpiNamedEvent:
 	  case vpiIntegerVar:
-//	  case vpiParameter:
 	  case vpiRealVar:
 	  case vpiMemoryWord:
 	  case vpiReg:
@@ -665,8 +659,7 @@ static void scan_item(unsigned depth, vpiHandle item, int skip)
 		    type, size, ident, prefix, name);
 
 	      /* Add a range for vectored values. */
-	    if (vpi_get(vpiSize, item) > 1
-		|| vpi_get(vpiLeftRange, item) != 0) {
+	    if (size > 1 || vpi_get(vpiLeftRange, item) != 0) {
 		  fprintf(dump_file, " [%i:%i]",
 			  (int)vpi_get(vpiLeftRange, item),
 			  (int)vpi_get(vpiRightRange, item));
@@ -691,7 +684,6 @@ static void scan_item(unsigned depth, vpiHandle item, int skip)
 			           "previously scanned scope %s.\n", fullname);
 		  } else {
 			vcd_names_add(&vcd_tab, fullname);
-			vcd_names_sort(&vcd_tab);
 		  }
 
 		  name = vpi_get_str(vpiName, item);
@@ -755,13 +747,13 @@ static PLI_INT32 sys_dumpvars_calltf(PLI_BYTE8*name)
       if (dump_file == 0) {
 	    open_dumpfile(callh);
 	    if (dump_file == 0) {
-		  vpi_free_object(argv);
+		  if (argv) vpi_free_object(argv);
 		  return 0;
 	    }
       }
 
       if (install_dumpvars_callback()) {
-	    vpi_free_object(argv);
+	    if (argv) vpi_free_object(argv);
 	    return 0;
       }
 
@@ -822,6 +814,8 @@ static PLI_INT32 sys_dumpvars_calltf(PLI_BYTE8*name)
 	    dep = draw_scope(item, callh);
 
 	    scan_item(depth, item, 0);
+	      /* The scope list must be sorted after we scan an item.  */
+	    vcd_names_sort(&vcd_tab);
 
 	    while (dep--) fprintf(dump_file, "$upscope $end\n");
 
