@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2008-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -17,17 +17,15 @@
  *    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+# include  "version_base.h"
 # include  "vpi_priv.h"
 # include  "schedule.h"
-# include  <stdio.h>
-# include  <stdarg.h>
-# include  <string.h>
-# include  <assert.h>
-#ifdef HAVE_MALLOC_H
-# include  <malloc.h>
-#endif
-# include  <stdlib.h>
-# include  <math.h>
+# include  <cstdio>
+# include  <cstdarg>
+# include  <cstring>
+# include  <cassert>
+# include  <cstdlib>
+# include  <cmath>
 
 vpi_mode_t vpi_mode_flag = VPI_MODE_NONE;
 FILE*vpi_trace = 0;
@@ -448,7 +446,7 @@ PLI_INT32 vpi_get_vlog_info(p_vpi_vlog_info vlog_info_p)
 void vpi_set_vlog_info(int argc, char** argv)
 {
     static char icarus_product[] = "Icarus Verilog";
-    static char icarus_version[] = "$Name:  $";
+    static char icarus_version[] = VERSION;
     vpi_vlog_info.product = icarus_product;
     vpi_vlog_info.version = icarus_version;
     vpi_vlog_info.argc    = argc;
