@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2001-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -29,13 +29,10 @@
 #ifdef CHECK_WITH_VALGRIND
 # include  "vvp_cleanup.h"
 #endif
-# include  <stdio.h>
-#ifdef HAVE_MALLOC_H
-# include  <malloc.h>
-#endif
-# include  <stdlib.h>
-# include  <string.h>
-# include  <assert.h>
+# include  <cstdio>
+# include  <cstdlib>
+# include  <cstring>
+# include  <cassert>
 
 static const struct __vpirt vpip_systask_def_rt = {
       vpiSysTask,
@@ -550,6 +547,79 @@ struct __vpiUserSystf* vpip_find_systf(const char*name)
       return 0;
 }
 
+/*
+ * To get better error message we need to cache the vpi_call fail
+ * information so that we can print the file name.
+ */
+enum vpi_call_error_type {VPI_CALL_NO_DEF, VPI_CALL_TASK_AS_FUNC,
+                          VPI_CALL_FUNC_AS_TASK};
+typedef struct vpi_call_error {
+      vpi_call_error_type type;
+      char *name;
+      long file_idx;
+      long lineno;
+} vpi_call_error_s, *vpi_call_error_p;
+
+static vpi_call_error_p vpi_call_error_lst = NULL;
+static unsigned vpi_call_error_num = 0;
+
+static void add_vpi_call_error(vpi_call_error_type type, const char *name,
+                               long file_idx, long lineno)
+{
+      vpi_call_error_lst = (vpi_call_error_p)
+                            realloc((void *)vpi_call_error_lst,
+                                    (vpi_call_error_num + 1) *
+                                    sizeof(vpi_call_error_s));
+      vpi_call_error_lst[vpi_call_error_num].type = type;
+      vpi_call_error_lst[vpi_call_error_num].name = strdup(name);
+      vpi_call_error_lst[vpi_call_error_num].file_idx = file_idx;
+      vpi_call_error_lst[vpi_call_error_num].lineno = lineno;
+      vpi_call_error_num += 1;
+}
+
+void print_vpi_call_errors()
+{
+      for (unsigned idx = 0; idx < vpi_call_error_num; idx += 1) {
+	    switch (vpi_call_error_lst[idx].type) {
+		case VPI_CALL_NO_DEF:
+		  fprintf(stderr, "%s:%d: Error: System task/function %s() is "
+		                  "not defined by any module.\n",
+		                  file_names[vpi_call_error_lst[idx].file_idx],
+		                  (int)vpi_call_error_lst[idx].lineno,
+		                  vpi_call_error_lst[idx].name);
+		  break;
+		case VPI_CALL_TASK_AS_FUNC:
+		  fprintf(stderr, "%s:%d: Error: %s() is a system task, it "
+			          "cannot be called as a function.\n",
+		                  file_names[vpi_call_error_lst[idx].file_idx],
+		                  (int)vpi_call_error_lst[idx].lineno,
+		                  vpi_call_error_lst[idx].name);
+		  break;
+		case VPI_CALL_FUNC_AS_TASK:
+		  fprintf(stderr, "%s:%d: Error: %s() is a system function, it "
+			          "cannot be called as a task.\n",
+		                  file_names[vpi_call_error_lst[idx].file_idx],
+		                  (int)vpi_call_error_lst[idx].lineno,
+		                  vpi_call_error_lst[idx].name);
+		  break;
+	    }
+	    free(vpi_call_error_lst[idx].name);
+      }
+      free(vpi_call_error_lst);
+}
+
+static void cleanup_vpi_call_args(unsigned argc, vpiHandle*argv)
+{
+#ifdef CHECK_WITH_VALGRIND
+      if (argc) {
+	    struct __vpiSysTaskCall*obj = new struct __vpiSysTaskCall;
+	    obj->nargs = argc;
+	    obj->args  = argv;
+	    vpi_call_delete(&obj->base);
+      }
+#endif
+}
+
 /*
  * A vpi_call is actually built up into a vpiSysTaskCall VPI object
  * that refers back to the vpiUserSystf VPI object that is the
@@ -569,16 +639,17 @@ vpiHandle vpip_build_vpi_call(const char*name, unsigned vbit, int vwid,
 {
       struct __vpiUserSystf*defn = vpip_find_systf(name);
       if (defn == 0) {
-	    fprintf(stderr, "%s: This task not defined "
-		    "by any modules. I cannot compile it.\n", name);
+	    add_vpi_call_error(VPI_CALL_NO_DEF, name, file_idx, lineno);
+	    cleanup_vpi_call_args(argc, argv);
 	    return 0;
       }
 
       switch (defn->info.type) {
 	  case vpiSysTask:
 	    if (vwid != 0 || fnet != 0) {
-		  fprintf(stderr, "%s: This is a system Task, "
-			  "you cannot call it as a Function\n", name);
+		  add_vpi_call_error(VPI_CALL_TASK_AS_FUNC, name, file_idx,
+		                     lineno);
+		  cleanup_vpi_call_args(argc, argv);
 		  return 0;
 	    }
 	    assert(vbit == 0);
@@ -586,14 +657,16 @@ vpiHandle vpip_build_vpi_call(const char*name, unsigned vbit, int vwid,
 
 	  case vpiSysFunc:
 	    if (vwid == 0 && fnet == 0) {
-		  fprintf(stderr, "%s: This is a system Function, "
-			  "you cannot call it as a Task\n", name);
+		  add_vpi_call_error(VPI_CALL_FUNC_AS_TASK, name, file_idx,
+		                     lineno);
+		  cleanup_vpi_call_args(argc, argv);
 		  return 0;
 	    }
 	    break;
 
 	  default:
-	    fprintf(stderr, "Unsupported type %d.\n", (int)defn->info.type);
+	    fprintf(stderr, "Unsupported call type %d.\n",
+	                    (int)defn->info.type);
 	    assert(0);
       }
 
@@ -644,6 +717,8 @@ vpiHandle vpip_build_vpi_call(const char*name, unsigned vbit, int vwid,
 void vpi_call_delete(vpiHandle item)
 {
       struct __vpiSysTaskCall*obj = (struct __vpiSysTaskCall *) item;
+	/* The object can be NULL if there was an error. */
+      if (!obj) return;
       for (unsigned arg = 0; arg < obj->nargs; arg += 1) {
 	    switch (obj->args[arg]->vpi_type->type_code) {
 		case vpiConstant:
