@@ -21,11 +21,11 @@
 
 # include  "config.h"
 # include  "vpi_user.h"
-# include  <stddef.h>
-# include  <stdlib.h>
-# include  <string.h>
+# include  <cstddef>
+# include  <cstdlib>
+# include  <cstring>
 # include  <new>
-# include  <assert.h>
+# include  <cassert>
 
 #ifdef HAVE_IOSFWD
 # include  <iosfwd>
@@ -829,7 +829,7 @@ inline vvp_vector8_t::vvp_vector8_t(unsigned size__)
 : size_(size__)
 {
       if (size_ <= PTR_THRESH) {
-	    new (val_) vvp_scalar_t[PTR_THRESH];
+	    new (reinterpret_cast<void*>(val_)) vvp_scalar_t[PTR_THRESH];
       } else {
 	    ptr_ = new vvp_scalar_t[size_];
       }
